/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#include <QApplication>
#include <QStyle>
#include <QPalette>
#include <cmath>

#include "applicationtheme.h"

TApplicationTheme::TApplicationTheme(void)
{
	QString								style_name;
	
	d_base_palette = QApplication::style()->standardPalette();
	d_current_theme = TApplicationTheme::DEFAULT;
	
	style_name = QString::fromLatin1(QApplication::style()->metaObject()->className());
	d_enable_theme = style_name.compare(style_name,QStringLiteral("QFusionStyle")) == 0;
}

TApplicationTheme::~TApplicationTheme(void)
{
}

QStringList TApplicationTheme::Theme_List(void) const
{
	QStringList							list;
	
	list.push_back(QStringLiteral("Standard"));
	list.push_back(QStringLiteral("Bright"));
	list.push_back(QStringLiteral("Dark"));
	list.push_back(QStringLiteral("Red"));
	list.push_back(QStringLiteral("Green"));
	list.push_back(QStringLiteral("Blue"));
	list.push_back(QStringLiteral("Yellow"));
	list.push_back(QStringLiteral("Cyan"));
	list.push_back(QStringLiteral("Magenta"));
	
	return list;
}

bool TApplicationTheme::Set_Theme(
	const QString						&name)
{
	if(!d_enable_theme)
	{
		return false;
	}

	if(name.compare(QStringLiteral("Standard"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::DEFAULT);
	}
	else if(name.compare(QStringLiteral("Bright"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::BRIGHT);
	}
	else if(name.compare(QStringLiteral("Dark"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::DARK);
	}
	else if(name.compare(QStringLiteral("Red"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::RED);
	}
	else if(name.compare(QStringLiteral("Green"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::GREEN);
	}
	else if(name.compare(QStringLiteral("Blue"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::BLUE);
	}
	else if(name.compare(QStringLiteral("Yellow"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::YELLOW);
	}
	else if(name.compare(QStringLiteral("Cyan"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::CYAN);
	}
	else if(name.compare(QStringLiteral("Magenta"),Qt::CaseInsensitive) == 0)
	{
		return this->Set_Theme(TApplicationTheme::MAGENTA);
	}
	
	return false;
}

bool TApplicationTheme::Set_Theme(
	const TTheme						theme)
{
	QPalette							palette;
	QColor								color;
	
	if(!d_enable_theme)
	{
		return false;
	}
	
	palette = d_base_palette;
		
	switch(theme)
	{
		case TApplicationTheme::DEFAULT:
			break;
			
		case TApplicationTheme::DARK:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base)));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window)));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase)));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText)));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark)));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow)));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button)));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link)));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight)));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText)));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText)));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text)));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase)));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText)));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Darken_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText)));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Base)));
			palette.setColor(QPalette::Active,QPalette::Window,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Window)));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase)));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText)));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Dark)));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow)));
			palette.setColor(QPalette::Active,QPalette::Button,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Button)));
			palette.setColor(QPalette::Active,QPalette::Link,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Link)));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight)));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText)));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText)));
			palette.setColor(QPalette::Active,QPalette::Text,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::Text)));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase)));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText)));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Darken_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText)));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base)));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window)));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase)));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText)));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark)));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow)));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button)));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link)));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight)));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText)));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText)));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text)));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase)));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText)));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Darken_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText)));
			break;
			
		case TApplicationTheme::BRIGHT:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Base)));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Window)));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase)));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText)));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Dark)));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Shadow)));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Button)));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Link)));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Highlight)));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::BrightText)));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText)));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::Text)));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase)));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::WindowText)));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Increase_Contrast(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText)));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Base)));
			palette.setColor(QPalette::Active,QPalette::Window,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Window)));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::AlternateBase)));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::ToolTipText)));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Dark)));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Shadow)));
			palette.setColor(QPalette::Active,QPalette::Button,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Button)));
			palette.setColor(QPalette::Active,QPalette::Link,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Link)));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Highlight)));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::BrightText)));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::ButtonText)));
			palette.setColor(QPalette::Active,QPalette::Text,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::Text)));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase)));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::WindowText)));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Increase_Contrast(d_base_palette.color(QPalette::Active,QPalette::HighlightedText)));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Base)));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Window)));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase)));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText)));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Dark)));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Shadow)));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Button)));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Link)));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Highlight)));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::BrightText)));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText)));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::Text)));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase)));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::WindowText)));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Increase_Contrast(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText)));
			break;
			
		case TApplicationTheme::RED:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText),TApplicationTheme::ROT_RED));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Base),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Window),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Dark),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Button),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Link),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Text),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText),TApplicationTheme::ROT_RED));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText),TApplicationTheme::ROT_RED));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText),TApplicationTheme::ROT_RED));
			break;
			
		case TApplicationTheme::GREEN:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText),TApplicationTheme::ROT_GREEN));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Base),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Window),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Dark),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Button),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Link),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Text),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText),TApplicationTheme::ROT_GREEN));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText),TApplicationTheme::ROT_GREEN));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText),TApplicationTheme::ROT_GREEN));
			break;
			
		case TApplicationTheme::BLUE:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText),TApplicationTheme::ROT_BLUE));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Base),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Window),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Dark),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Button),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Link),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Text),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText),TApplicationTheme::ROT_BLUE));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText),TApplicationTheme::ROT_BLUE));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText),TApplicationTheme::ROT_BLUE));
			break;
			
		case TApplicationTheme::YELLOW:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText),TApplicationTheme::ROT_YELLOW));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Base),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Window),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Dark),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Button),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Link),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Text),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText),TApplicationTheme::ROT_YELLOW));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText),TApplicationTheme::ROT_YELLOW));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText),TApplicationTheme::ROT_YELLOW));
			break;

		case TApplicationTheme::CYAN:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText),TApplicationTheme::ROT_CYAN));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Base),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Window),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Dark),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Button),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Link),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Text),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText),TApplicationTheme::ROT_CYAN));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText),TApplicationTheme::ROT_CYAN));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText),TApplicationTheme::ROT_CYAN));
			break;

		case TApplicationTheme::MAGENTA:
			palette.setColor(QPalette::Disabled,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Base),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Window),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::AlternateBase),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Dark),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Shadow),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Button),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Link),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Highlight),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::BrightText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ButtonText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::Text),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::ToolTipBase),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::WindowText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Disabled,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Disabled,QPalette::HighlightedText),TApplicationTheme::ROT_MAGENTA));
			
			palette.setColor(QPalette::Active,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Base),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Window),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::AlternateBase),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Dark),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Shadow),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Button),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Link),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Highlight),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::BrightText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ButtonText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::Text),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::ToolTipBase),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::WindowText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Active,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Active,QPalette::HighlightedText),TApplicationTheme::ROT_MAGENTA));
			
			palette.setColor(QPalette::Inactive,QPalette::Base,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Base),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Window,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Window),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::AlternateBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::AlternateBase),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Dark,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Dark),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Shadow,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Shadow),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Button,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Button),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Link,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Link),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Highlight,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Highlight),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::BrightText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::BrightText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::ButtonText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ButtonText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::Text,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::Text),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::ToolTipBase,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::ToolTipBase),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::WindowText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::WindowText),TApplicationTheme::ROT_MAGENTA));
			palette.setColor(QPalette::Inactive,QPalette::HighlightedText,this->Rotate_Color(d_base_palette.color(QPalette::Inactive,QPalette::HighlightedText),TApplicationTheme::ROT_MAGENTA));
			break;

	}

	d_current_theme = theme;
	
	QApplication::setPalette(palette);
	
	return true;
}

QColor TApplicationTheme::Increase_Contrast(
	const QColor						color)
{
	qreal								value;
	QColor								res_color;
	
	res_color.setAlphaF(color.alphaF());
	
	value = color.redF();
	if(value < 0.5)
	{
		value *= value;
	}
	else
	{
		value = (1.0 - value);
		value *= value;
		value = (1.0 - value);
	}
	res_color.setRedF(value);
	
	value = color.greenF();
	if(value < 0.5)
	{
		value *= value;
	}
	else
	{
		value = (1.0 - value);
		value *= value;
		value = (1.0 - value);
	}
	res_color.setGreenF(value);
	
	value = color.blueF();
	if(value < 0.5)
	{
		value *= value;
	}
	else
	{
		value = (1.0 - value);
		value *= value;
		value = (1.0 - value);
	}
	res_color.setBlueF(value);
		
	return res_color;
}

QColor TApplicationTheme::Darken_Color(
	const QColor						color)
{
	qreal								value;
	QColor								res_color;
	static const double					SCALE_RANGE(0.85);
	
	res_color.setAlphaF(color.alphaF());
	
	value = color.redF();
	value = (1.0 - SCALE_RANGE) + (1.0 - value) * SCALE_RANGE;
	res_color.setRedF(value);
	
	value = color.greenF();
	value = (1.0 - SCALE_RANGE) + (1.0 - value) * SCALE_RANGE;
	res_color.setGreenF(value);
	
	value = color.blueF();
	value = (1.0 - SCALE_RANGE) + (1.0 - value) * SCALE_RANGE;
	res_color.setBlueF(value);
	
	return res_color;
}

QColor TApplicationTheme::Rotate_Color(
	const QColor						color,
	TApplicationTheme::TRotationColor	rot_color)
{
	QColor								res_color;
	qreal								r,g,b;
	qreal								length;
	static const double					SCALE_VALUE(1.25);
	
	res_color.setAlphaF(color.alphaF());
	
	r = color.redF();
	g = color.greenF();
	b = color.blueF();

	switch(rot_color)
	{
		case TApplicationTheme::ROT_RED:
			r *= SCALE_VALUE;
			g /= SCALE_VALUE;
			b /= SCALE_VALUE;
			break;
			
		case TApplicationTheme::ROT_GREEN:
			r /= SCALE_VALUE;
			g *= SCALE_VALUE;
			b /= SCALE_VALUE;
			break;
			
		case TApplicationTheme::ROT_BLUE:
			r /= SCALE_VALUE;
			g /= SCALE_VALUE;
			b *= SCALE_VALUE;
			break;
			
		case TApplicationTheme::ROT_YELLOW:
			r *= SCALE_VALUE;
			g *= SCALE_VALUE;
			b /= SCALE_VALUE;
			break;
			
		case TApplicationTheme::ROT_CYAN:
			r /= SCALE_VALUE;
			g *= SCALE_VALUE;
			b *= SCALE_VALUE;
			break;
			
		case TApplicationTheme::ROT_MAGENTA:
			r *= SCALE_VALUE;
			g /= SCALE_VALUE;
			b *= SCALE_VALUE;
			break;
	}

	length = r;
	if(g > length) length = g;
	if(b > length) length = b;
	
	// only scale if length is greater than 1
	if(length > 1.0)
	{
		r /= length;
		g /= length;
		b /= length;
	}
	
	// increasee contrast
	if(r < 0.5)
	{
		r *= r;
	}
	else
	{
		r = (1.0 - r);
		r *= r;
		r = (1.0 - r);
	}
	
	if(g < 0.5)
	{
		g *= g;
	}
	else
	{
		g = (1.0 - g);
		g *= g;
		g = (1.0 - g);
	}
	
	if(b < 0.5)
	{
		b *= b;
	}
	else
	{
		b = (1.0 - b);
		b *= b;
		b = (1.0 - b);
	}

	
	res_color.setRgbF(r,g,b);
	return res_color;

}