/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef APPLICATIONTHEMEHEADERFILE
#define APPLICATIONTHEMEHEADERFILE

#include <QColor>
#include <QStringList>

class QPalette;

class TApplicationTheme
{
public:
	
enum TTheme		// technically more of a color than a real theme
{
	DEFAULT=0,
	BRIGHT,
	DARK,
	RED,
	GREEN,
	BLUE,
	YELLOW,
	CYAN,
	MAGENTA
};
	
	
// CREATORS
	TApplicationTheme(void);
	~TApplicationTheme(void);
	
// ACCESSORS
	bool Is_Themes_Available(void) const {return d_enable_theme;}
	QStringList Theme_List(void) const;
	TTheme Current_Theme(void) const {return d_current_theme;}

// MANIPULATORS
	bool Set_Theme(const QString &name);
	bool Set_Theme(const TTheme theme);

private:
	
enum TRotationColor
{
	ROT_RED=0,
	ROT_GREEN,
	ROT_BLUE,
	ROT_YELLOW,
	ROT_CYAN,
	ROT_MAGENTA
};
	
	QPalette							d_base_palette;
	bool								d_enable_theme;
	TTheme								d_current_theme;
	
	QColor Increase_Contrast(const QColor color);	// set dark colors darker and light colors lighter
	QColor Darken_Color(const QColor color);	// invert and scales between 0.15-1.0
	QColor Rotate_Color(const QColor color,const TRotationColor rot_color);
	
// NOT IMPLEMENTED
	TApplicationTheme(const TApplicationTheme&);
	TApplicationTheme& operator=(const TApplicationTheme&);
};

#endif
