/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#include <QApplication>
#include <QWidget>
#include <QShowEvent>
#include <QResizeEvent>

#include "messagebox.h"

TMessageBox::TMessageBox(
	const QWidget 						*Parent)
:QMessageBox(const_cast<QWidget*>(Parent))
{
	d_FixedWidth = 500;
	this->setTextFormat(Qt::RichText);
    this->setStyleSheet("dialogbuttonbox-buttons-have-icons: 0;\nbutton-layout: 1;");
}

TMessageBox::~TMessageBox(void)
{

}


void TMessageBox::setText(
	const QString 						&Text)
{
	QMessageBox::setText(QString("<span style=\"font-size:10pt; font-weight:600; color:#000000;\" >%1</span>").arg(Text));
}

void TMessageBox::setInformativeText(
	const QString 						&Text)
{
	QMessageBox::setInformativeText(QString("<span style=\"font-size:10pt; font-weight:400; color:#000000;\" >%1</span>").arg(Text));
}

int TMessageBox::exec(void)
{
	int									code(QMessageBox::exec());

#ifdef Q_OS_QNX
	QWidget								*parent(this->parentWidget());

	if(parent)
	{
		QApplication::postEvent(parent,new QResizeEvent(this->size(),this->size()));
		QApplication::processEvents();
	}
#endif

	return code;
}


void TMessageBox::showEvent(
	QShowEvent							*Event)
{
	QMessageBox::showEvent(Event);
	this->setFixedWidth(d_FixedWidth);
}

void TMessageBox::resizeEvent(
	QResizeEvent						*Event)
{
	QMessageBox::resizeEvent(Event);
	this->setFixedWidth(d_FixedWidth);
}

