/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef DATAEDITORWIDGETHEADERFILE
#define DATAEDITORWIDGETHEADERFILE

#include <QWidget>
#include <QChar>
#include <vector>

class QLineEdit;
class QWidget;
class QVBoxLayout;
class QObject;
class QSpacerItem;

class TDataItemWidget;

class TDataEditorWidget : public QWidget
{
Q_OBJECT

public:

// CREATORS
	TDataEditorWidget(const QWidget *parent=0, Qt::WindowFlags flags=0);
	~TDataEditorWidget(void);

// ACCESSORS
	bool Data_Item_Changed(void) const {return d_data_item_changed;}
	bool Using_Simple_Editor(void) const {return d_simple_editor;}
	
	QString Simple_Editor_Data(void) const;
	QString Item_Widget_Data(const int index) const;

// MANIPULATORS
	void Set_Scale_Resolution(const int ival) {d_scale_resolution = ival;}	// ticks per millimeter

	void Reset(const bool use_simple_editor);
	void Set_Item_Widget_Count(const int count);
	void Set_Item_Widget_Data(const int index,const QChar item,const int value,const QString &description,const bool enable_edit,const bool enable_float_value = false);
	void Set_Simple_Editor_Data(const QString &text);

signals:

private slots:
	void Simple_Editor_Changed(void);
	void Int_Edited(int,const QString&);	// int has control id
	void Hex_Edited(int,const QString&);	// int has control id
	void Dec_Edited(int,const QString&);	// int has control id
	

private:
	QLineEdit							*d_active_line_edit;
	QWidget								*d_items_widget;
	QVBoxLayout							*d_items_widget_vlayout;
	QSpacerItem							*d_items_widget_vspacer;
	
	int									d_scale_resolution;
	std::vector<TDataItemWidget*>		d_data_widget_items;
	int									d_active_items;
	bool								d_simple_editor;
	bool								d_data_item_changed;

// NOT IMPLEMENTED
	TDataEditorWidget(const TDataEditorWidget&);
	TDataEditorWidget& operator=(const TDataEditorWidget&);
};

#endif
