/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef DOWNLOADEDITORHEADERFILE
#define DOWNLOADEDITORHEADERFILE

#include <QDialog>

#include "../../core/applicationtheme.h"

#include "sh32data.h"

class QLabel;
//class QPushButton;
class QAction;
class QComboBox;
class QSettings;
class QCloseEvent;
class QDragEnterEvent;
class QDropEvent;

class TDataEditorWidget;
class TFileLineWidget;

class TDownloadEditor : public QDialog
{
Q_OBJECT

public:

// CREATORS
	TDownloadEditor(const QWidget *parent=0, Qt::WindowFlags flags=0);
	virtual ~TDownloadEditor(void);

// ACCESSORS

// MANIPULATORS
	void Read_File(const QString &file_name);

signals:
	

private slots:
	void Line_Activated(int);
	void Theme_Changed(int);
	
public slots:
	void Key_Pressed(int);
	void Scale_Resolution_Changed(int);
	
	void Read_File(void);
	void Write_File(void);
	
protected:
	virtual void closeEvent(QCloseEvent *event);
	virtual void dragEnterEvent(QDragEnterEvent *DragEnterEvent);
	virtual void dropEvent(QDropEvent *DropEvent);
	
private:
	TApplicationTheme					d_application_theme;
	QAction								*d_load_file_action;
	QAction								*d_save_file_action;
	QComboBox							*d_theme_combo;
	QLabel								*d_active_file_label;
	QLabel								*d_file_name_label;
	TDataEditorWidget					*d_data_editor_widget;
	TFileLineWidget						*d_file_line_widget;
	
	QSettings							*d_settings;
	int									d_active_line_index;
	int									d_active_command_id;
	bool								d_data_changed;
	
	TSH32Data							d_sh32_data;
	
	
	void Process_Line(const QString &text);
	int Get_Command_Id(const QString &command_text) const;
	int Get_Entry_Value(const QChar entry_id,const QString &line,bool *valid) const;
	
	void Update_Active_Line(void);
	bool Update_Parameter(const QChar &entry_id,const QString &data,QString * const line) const;

// NOT IMPLEMENTED
	TDownloadEditor(const TDownloadEditor&);
	TDownloadEditor& operator=(const TDownloadEditor&);
};

#endif
