/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#ifndef FILELINEWIDGETHEADERFILE
#define FILELINEWIDGETHEADERFILE

#include <QWidget>
#include <QStringList>
#include <QFont>

//class QLabel;
class QLineEdit;
class QToolButton;
class QEvent;
class QObject;

class TFileLineWidget : public QWidget
{
Q_OBJECT

public:

// CREATORS
	TFileLineWidget(const QWidget *parent=0, Qt::WindowFlags flags=0);
	virtual ~TFileLineWidget(void);

// ACCESSORS
	QString Line(const int index) const;
	int	Scale_Resolution(void) const;
	bool File_Changed(void) const {return d_file_changed;}

// MANIPULATORS
	void Set_Line(const int index,const QString &text);
	void Set_Scale_Resolution(const int resolution);
	
	bool Read_File(const QString &file_name);
	bool Write_File(const QString &file_name);

signals:
	void Line_Activated(int);
	void Scale_Resolution_Changed(int);

public slots:
	void Increment_Active_Line(void);
	void Decrement_Active_Line(void);
	void Scale_Resolution_Edited(const QString&);
	
private slots:
	void Set_Active_Line(int);
	
protected:
	virtual bool eventFilter(QObject *object, QEvent *event);

private:
	QLineEdit							*d_scale_resolution_edit;
	QToolButton							*d_down_button;
	QToolButton							*d_up_button;
	QWidget								*d_display_widget;
	
	QFont								d_display_font;
	int									d_display_line_height;
	int									d_display_line_indent;
	bool								d_display_initialize;
	
	int									d_active_line_index;
	QStringList							d_file_lines;
	bool								d_file_changed;
	
	void Draw_Display_Widget(QWidget * const widget);
	void Mouse_Click(QWidget * const widget,const QPoint &click_position);


// NOT IMPLEMENTED
	TFileLineWidget(const TFileLineWidget&);
	TFileLineWidget& operator=(const TFileLineWidget&);
};

#endif
