/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#include <QApplication>
#include <QStyleFactory>
#include <QIcon>
#include <QStringList>
#include <QDir>

#ifdef Q_OS_MAC
#include "../../core/nspool.h"
#endif

#include "globalkeyevent.h"
#include "downloadeditor.h"

int main(int argc, char *argv[])
{
	int									ret_value;
	TGlobalKeyEvent						*global_key_event;
	QStringList							arguments;
	QDir								dir;
	QString								file_name;

#ifdef Q_OS_MAC
		TNSPool *nspool = new TNSPool();
#endif
//	Q_INIT_RESOURCE(downloadeditor);
	QApplication app(argc, argv);

#ifndef Q_OS_MAC
	QApplication::setStyle(QStyleFactory::create("fusion"));
#endif
	
	app.setWindowIcon(QIcon(QStringLiteral(":/icons/downloadeditor.png")));
	
	global_key_event = new TGlobalKeyEvent();

	TDownloadEditor *w = new TDownloadEditor;
	
	app.installEventFilter(global_key_event);

	QObject::connect(global_key_event,SIGNAL(Key_Pressed(int)),w,SLOT(Key_Pressed(int)));
	
	w->show();
	
	arguments = QCoreApplication::arguments();
	dir.setPath(QDir::currentPath());

	if(arguments.size() > 1)
	{
		file_name = dir.absoluteFilePath(arguments.at(arguments.size()-1));
		file_name = QDir::cleanPath(file_name);

		if(QFile::exists(file_name))
		{
			w->Read_File(file_name);
		}
	}

	ret_value = app.exec();

#ifdef Q_OS_MAC
	delete nspool;
#endif
	
	app.removeEventFilter(global_key_event);
	global_key_event->deleteLater();

	delete w;
	return ret_value;
}
