/////////////////////////////////////////////////////////////////////
//
//            X   X           X
//           XXX XX         XX
//          XXXXXXXX      XXX
//         XX X XXXXXXXXXXX
//        XXXXX XXXXXXXXX
//       XXXXX XXXXXXXXXX
//            XXX XXX XXX
//           XXX XX   XX
//           X   X     X
//
//    Copyright (C) 2003-2019  Ron Jakl
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
/////////////////////////////////////////////////////////////////////

#include "sh32data.h"

TSH32Data::TSH32Data(void)
{
}

TSH32Data::~TSH32Data(void)
{
}

TSH32DataEntry TSH32Data::Get_Entry(
	const int							command_id) const
{
	TSH32DataEntry						data_entry;
	TSH32DataEntryItem					data_entry_item;
	
	data_entry.command_id = -1;
	
	switch(command_id)
	{
		case 0x01:	// velocity
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis maximum velocity");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis maximum velocity");
			
			data_entry.entry_items.push_back(data_entry_item);

			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis maximum velocity");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis maximum velocity");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x02:	// acceleration
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Maximum 3D acceleration");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x03:	// system gain
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis system gain");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis system gain");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis system gain");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis system gain");
			
			data_entry.entry_items.push_back(data_entry_item);
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("All axis system gain");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x04:	// feedforward multiplier
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Feedforward multiplier");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x05:	// touch trigger hit velocity
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Probe maximum touch speed");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x06:	// probe overtravel, max and min
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Probe maximum overtravel limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('L');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Probe minimum overtravel limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x07:	// digi lock gain
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("DIGI lock gain");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x08:	// limit sample zone
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Sample zone around hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x09:	// positive hardware check point
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis positive hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis positive hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis positive hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis positive hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x0c:	// acceleration feed forward
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis acceleration feed-forward (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis acceleration feed-forward (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis acceleration feed-forward (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis acceleration feed-forward (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x0d:	// PID derivitive gain
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis PID derivitive gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis PID derivitive gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis PID derivitive gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis PID derivitive gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x0e:	// PID integral gain
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis PID integral gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis PID integral gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis PID integral gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis PID integral gain (Tackless Motor)");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x10:	// negative hardware check point
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis negative hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis negative hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis negative hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis negative hardware checkpoint");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x11:	// positive axis limit
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis positive software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis positive software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis positive software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis positive software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x12:	// negative axis limit
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis negative software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis negative software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis negative software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis negative software limit");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x13:	// in position zone
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis in position zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis in position zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis in position zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis in position zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x15:	// slow continuous jog
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Slow continuous jog P1");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Slow continuous jog P2");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x16:	// fast continuous jog
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fast continuous jog P1");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fast continuous jog P2");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x17:	// fixed rate jog
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fixed rate jog P1");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fixed rate jog P2");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x18:	// slow incremental jog
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Slow incremental jog P1");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Slow incremental jog P2");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Slow incremental jog distance");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x19:	// fast incremental jog
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fast incremental jog P1");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fast incremental jog P2");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Fast incremental jog distance");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x1A:	// digi lock zone
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("X axis DIGI lock zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Y axis DIGI lock zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Z axis DIGI lock zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("W axis DIGI lock zone");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x1B:	// jog acceleration multiplier
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('Q');
			data_entry_item.can_be_value = true;
			data_entry_item.description = QStringLiteral("Jog acceleration multiplier (1000 = 100%)");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x1D:	// axis jog polarity
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis jog box polarity normal/reversed [0/FF]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis jog box polarity normal/reversed [0/FF]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis jog box polarity normal/reversed [0/FF]");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x25:	// axis resolution
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis resolution [0 to disable]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis resolution [0 to disable]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis resolution [0 to disable]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis resolution [0 to disable]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Motorized probe [9 enable, 0 disable]");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x26:	// rotary axis wrap count
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Rotary axis wrap count");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x29:	// home interlocks
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('V');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Homing interlock");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis home interlock");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis home interlock");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis home interlock");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis home interlock");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x2a:	// homing velocity
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("X axis homing velocity constant");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Y axis homing velocity constant");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Z axis homing velocity constant");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("W axis homing velocity constant");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x2d:	// unsolicited status report mask
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Status report mask");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x52:	// vector reporting enabled
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('U');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Vector reporting enabled/disabled [0/FF]");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x60:	// flexible parameter 1
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 1A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 1B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 1C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 1D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x61:	// flexible parameter 2
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 2A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 2B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 2C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 2D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x62:	// flexible parameter 3
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 3A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 3B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 3C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 3D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x63:	// flexible parameter 4
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 4A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 4B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 4C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 4D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x64:	// flexible parameter 5
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 5A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 5B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 5C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 5D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x65:	// flexible parameter 6
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 6A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 6B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 6C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 6D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x66:	// flexible parameter 7
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 7A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 7B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 7C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 7D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x67:	// flexible parameter 8
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 8A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 8B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 8C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 8D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x68:	// flexible parameter 9
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 9A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 9B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 9C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 9D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x69:	// flexible parameter 10
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 10A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 10B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 10C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 10D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x6a:	// flexible parameter 11
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 11A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 11B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 11C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 11D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x6b:	// flexible parameter 12
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 12A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 12B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 12C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 12D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x6c:	// flexible parameter 13
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 13A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 13B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 13C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 13D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x6d:	// flexible parameter 14
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 14A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 14B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 14C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 14D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

		case 0x6e:	// flexible parameter 15
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 15A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 15B");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 15C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 15D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;
			
		case 0x6f:	// flexible parameter 16
			data_entry.command_id = command_id;
			
			data_entry_item.entry_id = QChar('X');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 16A");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Y');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 16B.\nProbe type (integer): PI6 [32], TTL [33], PICS [34]");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('Z');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 16C");
			
			data_entry.entry_items.push_back(data_entry_item);
			
			data_entry_item.entry_id = QChar('W');
			data_entry_item.can_be_value = false;
			data_entry_item.description = QStringLiteral("Flexible parameter 16D");
			
			data_entry.entry_items.push_back(data_entry_item);
			break;

	}
	
	return data_entry;

}

